@@ -94,7 +94,8 @@ class UnexpectedEOF(Exception):
 class AlreadyRead(Exception):
     """ raised when a response have already been read """
     
-    
+class ProxyError(Exception):
+    pass 
     
 #############################
 # HTTP parser errors
@@ -165,3 +166,8 @@ class ChunkMissingTerminator(ParseException):
     
     def __str__(self):
         return "Invalid chunk terminator is not '\\r\\n': %r" % self.term
+
+class HeaderLimit(ParseException):
+    """ exception raised when we gore more headers than 
+    max_header_count
+    """
